==> apache-VCL-2.4.2.tar.bz2: apache-VCL-2.4.2/web/js/nls/es_MX/messages.js <==
/*
* Licensed to the Apache Software Foundation (ASF) under one or more
* contributor license agreements.  See the NOTICE file distributed with
* this work for additional information regarding copyright ownership.
* The ASF licenses this file to You under the Apache License, Version 2.0
* (the "License"); you may not use this file except in compliance with
* the License.  You may obtain a copy of the License at
*
*     http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

nlsmessages = {
'Create / Update an Image':'',
'You do not have access to create or update any images.':'',
'(New Profile)':'',
'The start day and time must be in the future.':'',
'The end time must be at least 30 minutes in the future.':'',
'The end time must be after the start time.':'',
'The end time is too close to the start time.':'',
'Times cannot be suggested for cluster reservations': 'No se pueden sugerir horarios para la reservacin de clusters',
'Cancel': 'Cancelar',
'Okay': 'Correcto',
'Create Reservation':'Crear Reservacin',
'Modify Reservation': 'Modificar Reservacin',
"Create Imaging Reservation":"",
"Deploy Server":"",
'Please select a valid environment.': 'Por favor seleccione un ambiente valido',
'View Available Times': 'ver horarios disponibles',
'hour': 'hora',
'days': 'das',
'hours': 'horas',
"There are multiple versions of this environment available.":"Existen varias versiones de este ambiente disponibles.",
"Please select the version you would like to check out:":"Por favor seleccione la versin que desea usar:",
'Select Image Revisions':'',
'Revision':'',
'User':'Usuario',
'Created':'Creada',
'Production':'',
'Working...':'',
'Loading...': 'Cargando',
'The end time must be later than the start time.': 'La hora final debe de ser ms tarde que la hora inicial',
'The reservation you selected<br>to edit has expired.<br><br>': 'La reservacin que usted selecciono<br>para editar ha expirado.<br><br>',
'The reservation you selected<br>to reboot has expired.<br><br>': 'La reservacin que usted selecciono<br> que reiniciara ha expirado.<br><br>',
'The reservation you selected<br>to reinstall has expired.<br><br>': 'La reservacin que usted selecciono<br> para reinstalar ha expirado.<br><br>',
'An invalid version was submitted.': 'Una versin invlida ha sido enviada.',
'(No description)':'',
'You do not have access to apply this server profile.':'',
'Delete':'Borrar',
'Undelete':'',
'Edit':'Editar',
'You do not have access to the submitted resource or group':'',
'Resource In Use':'',
'Problem encountered while attempting to delete resource. Please contact a system administrator.':'',
'false':'',
'true':'',
'Save Changes':'',
'Access denied to edit this item':'',
'Invalid network speed specified':'',
'Max Concurrent Usage must be between 0 and 255':'',
'Invalid value specified for \'Available for checkout\'':'',
'Invalid value specified for \'Check for logged in user\'':'',
'Invalid value specified for \'Users have administrative access\'':'',
'Invalid value specified for \'Set computer hostname\'':'',
'Invalid value specified for \'Use sysprep\'':'',
'Invalid Connect Methods specified':'',
'Add Subimage':'',
'(None)':'Ninguno',
'Remove Selected Subimage(s)':'',
'Add Method':'',
'There must be at least one item in Current Methods':'',
'Remove Selected Methods':'',
'You cannot delete the production revision.':'',
'Create Image':'Crear Ambiente',
'You must be the owner of the image to update it.':'',
'Remove': 'Borrar',
'The selected Block Request no longer exists.':'',
'These times overlap with an existing time slot': 'Este horario se empalma con una reservacin existente',
'The date must be today or later': 'La fecha debe de ser hoy o posterior',
'The date and times overlap with an existing time slot': 'La fecha y hora se traslapa con una reservacin existente',
'Please fix invalid values before submitting.': 'Por favor corrija los valores invlidos antes de enviar',
'Please fill in First Date of Usage': 'Por favor indique la primer fecha de uso',
'Please fill in Last Date of Usage': 'Por favor indique la ltima fecha de uso',
'The First Date of Usage must be today or later': 'La fecha de inicio debe de ser hoy o posterior',
'The Last Date of Usage must be the same or later than the First Date of Usage': 'La ltima fecha debe de ser igual o posterior a la fecha inicial',
'The Last Date of Usage must be today or later': 'La ltima fecha debe de ser hoy o posterior',
'Sunday': 'Domingo',
'Monday': 'Lunes',
'Tuesday': 'Martes',
'Wednesday': 'Mircoles',
'Thursday': 'Jueves',
'Friday': 'Viernes',
'Saturday': 'Sbado',
'At least one day must be checked when using "Repeating Weekly"': 'Por lo menos debe de seleccionar un da cuando usa "Repetir semanalmente"',
'At least one start/end combination must be entered when using "Repeating Weekly"': 'Por lo menos debe de seleccionar una combinacin de inicio/fin cuando usa "Repetir semanalmente"',
'When submitting "(group not listed)" as the user group, information must be included in the comments about what group needs to be created.': 'Cuando seleccione "(grupo no listado)" como el grupo de usuarios, debe de incluir en los comentarios que grupo necesita que sea generado',
'Name:': 'Nombre:',
'Owner:': 'Dueo',
'specified in comments': 'especificado en comentarios',
'Weekly': 'Semanalmente',
'First Date:': 'Primer fecha:',
'Last Date:': 'Ultima fecha:',
'Repeating on these days:': 'Repetir en estos das:',
'During these times:': 'En estos horarios:',
'At least one start/end combination must be entered when using "Repeating Monthly"': 'Por lo menos debe de existir una combinacin de incio/fin cuando usa "Repetir mensualmente"',
'Monthly': 'Mensualmente',
'Repeat on:': 'Repetir el:',
'of each month': 'de cada mes:',
'At least one date/start/end combination must be entered when using "List of Dates/Times"': 'Por lo menos debe de existir una fecha de inicio/fin cuando usa "Fechas y horas especficas"',
'List of Dates/Times': 'Lista de fechas/horarios',
'User Submitted Comments;': 'Comentarios enviados por el usuario;',
'Skip': 'Saltar',
'Use': 'Use',
'Total online:': 'Total en lnea',
}

==> apache-VCL-2.5.1.tar.bz2: apache-VCL-2.5.1/web/js/nls/es_MX/messages.js <==
/*
* Licensed to the Apache Software Foundation (ASF) under one or more
* contributor license agreements.  See the NOTICE file distributed with
* this work for additional information regarding copyright ownership.
* The ASF licenses this file to You under the Apache License, Version 2.0
* (the "License"); you may not use this file except in compliance with
* the License.  You may obtain a copy of the License at
*
*     http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

nlsmessages = {
'Create / Update an Image':'',
'You do not have access to create or update any images.':'',
'(New Profile)':'',
'The start day and time must be in the future.':'',
'The end time must be at least 30 minutes in the future.':'',
'The end time must be after the start time.':'',
'The end time is too close to the start time.':'',
'The submitted start time is in the past.':'El tiempo de inicio enviado est en el pasado.',
'Times cannot be suggested for cluster reservations': 'No se pueden sugerir horarios para la reservacin de clusters',
'Cancel': 'Cancelar',
'Okay': 'Correcto',
'Create Reservation':'Crear Reservacin',
'Modify Reservation': 'Modificar Reservacin',
'Create Imaging Reservation':"",
'Deploy Server':"",
'Please select a valid environment.': 'Por favor seleccione un ambiente valido',
'View Available Times': 'ver horarios disponibles',
'hour': 'hora',
'weeks':'',
'days': 'das',
'hours': 'horas',
'There are multiple versions of this environment available.':"Existen varias versiones de este ambiente disponibles.",
'Please select the version you would like to check out:':"Por favor seleccione la versin que desea usar:",
'Select Image Revisions':'',
'Revision':'',
'User':'Usuario',
'Created':'Creada',
'Production':'',
'Working...':'',
'Loading...': 'Cargando',
'The end time must be later than the start time.': 'La hora final debe de ser ms tarde que la hora inicial',
'The reservation you selected<br>to edit has expired.<br><br>': 'La reservacin que usted selecciono<br>para editar ha expirado.<br><br>',
'The reservation you selected<br>to reboot has expired.<br><br>': 'La reservacin que usted selecciono<br> que reiniciara ha expirado.<br><br>',
'The reservation you selected<br>to reinstall has expired.<br><br>': 'La reservacin que usted selecciono<br> para reinstalar ha expirado.<br><br>',
'An invalid version was submitted.': 'Una versin invlida ha sido enviada.',
'(No description)':'',
'You do not have access to apply this server profile.':'',
'Delete':'Borrar',
'Undelete':'',
'Edit':'Editar',
'You do not have access to the submitted resource or group':'',
'Resource In Use':'',
'Problem encountered while attempting to delete resource. Please contact a system administrator.':'',
'Unmatched or empty brackets ( [ and ] ) in subject':'',
'Unmatched or empty brackets ( [ and ] ) in message':'',
'Unmatched or empty brackets ( [ and ] ) in short message':'',
'false':'',
'true':'',
'Save Changes':'',
'Access denied to edit this item':'',
'Invalid network speed specified':'',
'Max Concurrent Usage must be between 0 and 255':'',
'Invalid value specified for \'Available for checkout\'':'',
'Invalid value specified for \'Check for logged in user\'':'',
'Invalid value specified for \'Users have administrative access\'':'',
'Invalid value specified for \'Set computer hostname\'':'',
'Invalid value specified for \'Use sysprep\'':'',
'Invalid Connect Methods specified':'',
'Add Subimage':'',
'(None)':'Ninguno',
'Remove Selected Subimage(s)':'',
'Add Method':'',
'There must be at least one item in Current Methods':'',
'Remove Selected Methods':'',
'You cannot delete the production revision.':'',
'Create Image':'Crear Ambiente',
'You must be the owner of the image to update it.':'',
'Remove': 'Borrar',
'The selected Block Request no longer exists.':'',
'These times overlap with an existing time slot': 'Este horario se empalma con una reservacin existente',
'The date must be today or later': 'La fecha debe de ser hoy o posterior',
'The date and times overlap with an existing time slot': 'La fecha y hora se traslapa con una reservacin existente',
'Please fix invalid values before submitting.': 'Por favor corrija los valores invlidos antes de enviar',
'Please fill in First Date of Usage': 'Por favor indique la primer fecha de uso',
'Please fill in Last Date of Usage': 'Por favor indique la ltima fecha de uso',
'The First Date of Usage must be today or later': 'La fecha de inicio debe de ser hoy o posterior',
'The Last Date of Usage must be the same or later than the First Date of Usage': 'La ltima fecha debe de ser igual o posterior a la fecha inicial',
'The Last Date of Usage must be today or later': 'La ltima fecha debe de ser hoy o posterior',
'Sunday': 'Domingo',
'Monday': 'Lunes',
'Tuesday': 'Martes',
'Wednesday': 'Mircoles',
'Thursday': 'Jueves',
'Friday': 'Viernes',
'Saturday': 'Sbado',
'At least one day must be checked when using "Repeating Weekly"': 'Por lo menos debe de seleccionar un da cuando usa "Repetir semanalmente"',
'At least one start/end combination must be entered when using "Repeating Weekly"': 'Por lo menos debe de seleccionar una combinacin de inicio/fin cuando usa "Repetir semanalmente"',
'When submitting "(group not listed)" as the user group, information must be included in the comments about what group needs to be created.': 'Cuando seleccione "(grupo no listado)" como el grupo de usuarios, debe de incluir en los comentarios que grupo necesita que sea generado',
'Name:': 'Nombre:',
'Owner:': 'Dueo',
'specified in comments': 'especificado en comentarios',
'Weekly': 'Semanalmente',
'First Date:': 'Primer fecha:',
'Last Date:': 'Ultima fecha:',
'Repeating on these days:': 'Repetir en estos das:',
'During these times:': 'En estos horarios:',
'At least one start/end combination must be entered when using "Repeating Monthly"': 'Por lo menos debe de existir una combinacin de incio/fin cuando usa "Repetir mensualmente"',
'Monthly': 'Mensualmente',
'Repeat on:': 'Repetir el:',
'of each month': 'de cada mes:',
'At least one date/start/end combination must be entered when using "List of Dates/Times"': 'Por lo menos debe de existir una fecha de inicio/fin cuando usa "Fechas y horas especficas"',
'List of Dates/Times': 'Lista de fechas/horarios',
'User Submitted Comments;': 'Comentarios enviados por el usuario;',
'Skip': 'Saltar',
'Use': 'Use',
'Total online:': 'Total en lnea',
'match':'coinciden',
'no match':'no coinciden',
'Error encountered:':'Error encontrado:',
'Please try again later':'Por favor intente de nuevo ms tarde',
'Values updated':'',
'Submit Changes':'',
'Add':'',
'Invalid item selected for new value':'',
'Invalid value submitted':'',
'Invalid item submitted for deletion':'',
'You do not have access to modify the submitted settings.':'',
'Invalid value submitted for ':'',
'NFS Mounts':'',
'NFS Mounts are NFS exports that are to be mounted within each reservation deployed by a given management node.<br>Values must be like':'',
'Invalid value - must be in the form':'',
'Messages':'',
'This section allows for configuration of messages that are sent to users and administrators about things such as reservations and image management. Every message has a default. Additionally, separate messages can be configured for each affiliation. Most of the messages will have parts that are in square brackets. These parts will have data substituted for them before the message is sent. A list of what can be used in squeare brackets can be found at the <a href=\"%s\">Apache VCL web site</a>. Some messages also have a short form that may be sent such as in the form of a popup within a reservation when the reservation is about to end.':'',
'Save Message':'',
'Delete Message and Use Default':'',
'The following messages have invalid items included for substitution. Please correct the message contents and save them again for the backend to validate.':'',
'Message type %s for affiliation %s successfully deleted':'',
'Invalid item submitted to save':'',
'Message successfully saved':'',
'No changes to submitted message. Nothing saved.':'',
'unset':'',
'1 hour':'',
'Default for User':'',
'Invalid Max Reservation Duration selected':'',
'minutes':'',
'Passwords do not match':''
}
